==> haskell-primitive-extras-0.10.1.10-10-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-primitive-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 primitive-extras
version:              0.10.1.10
visibility:           public
id:                   primitive-extras-0.10.1.10-KQlfAre5w27hlGY1UEdKb
key:                  primitive-extras-0.10.1.10-KQlfAre5w27hlGY1UEdKb
license:              MIT
copyright:            (c) 2018, Metrix.AI
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/metrix-ai/primitive-extras
synopsis:             Extras for the "primitive" library
description:
    Raw collection of extra utiltilies for the "primitive" library.

category:             Primitive
abi:                  ae4e8566561bd3a9ca0982bb750d9340
exposed:              True
exposed-modules:
    PrimitiveExtras.Bitmap PrimitiveExtras.By6Bits
    PrimitiveExtras.PrimArray PrimitiveExtras.PrimMultiArray
    PrimitiveExtras.SmallArray PrimitiveExtras.UnliftedArray

hidden-modules:
    PrimitiveExtras.FoldMs PrimitiveExtras.Folds
    PrimitiveExtras.Prelude PrimitiveExtras.Types

import-dirs:          /usr/lib/ghc-9.2.8/site-local/primitive-extras-0.10.1.10
library-dirs:         /usr/lib/ghc-9.2.8/site-local/primitive-extras-0.10.1.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-primitive-extras
hs-libraries:         HSprimitive-extras-0.10.1.10-KQlfAre5w27hlGY1UEdKb
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    cereal-0.5.8.3-9zcITCTkqXtHoa6jbeSF22
    deferred-folds-0.9.18.6-Pwh3CpSnDcBhrQmCCBHbc
    focus-1.0.3.2-FWjZdYkIKs76t6ifFeMJ1P
    foldl-1.4.15-7CQgIxRdHMl43eFeF0YiaO
    list-t-1.0.5.4-EElBG3sJmzVCDVVRwLKBmx
    primitive-0.7.4.0-7EmETL08CQ5nNVujSkVxd
    primitive-unlifted-0.1.3.1-43G9xtAV6asIt5V9W96WdP
    profunctors-5.6.2-6U8Fi3i5PNTJVkD3oayjry
    vector-0.13.1.0-AXstUsf4rEVFm5YPigldNP

haddock-interfaces:
    /usr/share/doc/haskell-primitive-extras/html/primitive-extras.haddock

haddock-html:         /usr/share/doc/haskell-primitive-extras/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-primitive-extras-0.10.1.10-11-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-primitive-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 primitive-extras
version:              0.10.1.10
visibility:           public
id:                   primitive-extras-0.10.1.10-DHnGg9fW5NkDnzF31waTOP
key:                  primitive-extras-0.10.1.10-DHnGg9fW5NkDnzF31waTOP
license:              MIT
copyright:            (c) 2018, Metrix.AI
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/metrix-ai/primitive-extras
synopsis:             Extras for the "primitive" library
description:
    Raw collection of extra utiltilies for the "primitive" library.

category:             Primitive
abi:                  68baf2c44671ede5356da0d8ac13fe98
exposed:              True
exposed-modules:
    PrimitiveExtras.Bitmap PrimitiveExtras.By6Bits
    PrimitiveExtras.PrimArray PrimitiveExtras.PrimMultiArray
    PrimitiveExtras.SmallArray PrimitiveExtras.UnliftedArray

hidden-modules:
    PrimitiveExtras.FoldMs PrimitiveExtras.Folds
    PrimitiveExtras.Prelude PrimitiveExtras.Types

import-dirs:          /usr/lib/ghc-9.2.8/site-local/primitive-extras-0.10.1.10
library-dirs:         /usr/lib/ghc-9.2.8/site-local/primitive-extras-0.10.1.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-primitive-extras
hs-libraries:         HSprimitive-extras-0.10.1.10-DHnGg9fW5NkDnzF31waTOP
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    cereal-0.5.8.3-9zcITCTkqXtHoa6jbeSF22
    deferred-folds-0.9.18.6-1rqky4GibVp2JEiBrPZfzR
    focus-1.0.3.2-9JTxZHxOb4j1brEHTBJ0LP
    foldl-1.4.15-BMq9vqWE12NFNWunFiSByH
    list-t-1.0.5.4-62hRrI58rfCHfRQASqaHPI
    primitive-0.7.4.0-5Nr7R1OcK3bE67TSpaATMA
    primitive-unlifted-0.1.3.1-IO36n7O1fMlFtDVZ1T8je5
    profunctors-5.6.2-6fayOniCA8C3jgmqYHlDfy
    vector-0.13.1.0-BOAscM7GxpQxkvUjpqER4

haddock-interfaces:
    /usr/share/doc/haskell-primitive-extras/html/primitive-extras.haddock

haddock-html:         /usr/share/doc/haskell-primitive-extras/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
